@@ -3,13 +3,16 @@ package postgres
 import (
 	"context"
 	"fmt"
+	"strings"
 
 	"github.com/spf13/cobra"
 	"github.com/superfly/flyctl/api"
 	"github.com/superfly/flyctl/client"
 	"github.com/superfly/flyctl/flypg"
 	"github.com/superfly/flyctl/internal/command"
+	"github.com/superfly/flyctl/internal/command/apps"
 	"github.com/superfly/flyctl/internal/flag"
+	mach "github.com/superfly/flyctl/internal/machine"
 	"github.com/superfly/flyctl/internal/prompt"
 	"github.com/superfly/flyctl/iostreams"
 )
@@ -60,6 +63,10 @@ func newCreate() *cobra.Command {
 			Name:        "snapshot-id",
 			Description: "Creates the volume with the contents of the snapshot",
 		},
+		flag.String{
+			Name:        "fork-from",
+			Description: "Specify a source Postgres application to fork from. Format: <app-name> or <app-name>:<volume-id>",
+		},
 		flag.String{
 			Name:        "image-ref",
 			Description: "Specify a non-default base image for the Postgres app",
@@ -88,7 +95,12 @@ func newCreate() *cobra.Command {
 // we pass the name, region and org to CreateCluster. Other flags that don't prompt may
 // be safely passed through from other commands.
 func run(ctx context.Context) (err error) {
-	appName := flag.GetString(ctx, "name")
+	var (
+		appName  = flag.GetString(ctx, "name")
+		client   = client.FromContext(ctx).API()
+		io       = iostreams.FromContext(ctx)
+		colorize = io.ColorScheme()
+	)
 
 	if appName == "" {
 		if appName, err = prompt.SelectAppName(ctx); err != nil {
@@ -97,22 +109,20 @@ func run(ctx context.Context) (err error) {
 	}
 
 	var org *api.Organization
-
 	org, err = prompt.Org(ctx)
 	if err != nil {
 		return
 	}
 
-	var region *api.Region
-
-	region, err = prompt.Region(ctx, !org.PaidPlan, prompt.RegionParams{
-		Message: "",
-	})
-	if err != nil {
-		return
+	params := &ClusterParams{
+		Password:   flag.GetString(ctx, "password"),
+		SnapshotID: flag.GetString(ctx, "snapshot-id"),
+		Detach:     flag.GetDetach(ctx),
+		Manager:    flypg.ReplicationManager,
+		Autostart:  flag.GetBool(ctx, "autostart"),
 	}
 
-	pgConfig := PostgresConfiguration{
+	pgConfig := &PostgresConfiguration{
 		Name:               appName,
 		VMSize:             flag.GetString(ctx, "vm-size"),
 		InitialClusterSize: flag.GetInt(ctx, "initial-cluster-size"),
@@ -120,18 +130,119 @@ func run(ctx context.Context) (err error) {
 		DiskGb:             flag.GetInt(ctx, "volume-size"),
 	}
 
-	params := &ClusterParams{
-		PostgresConfiguration: pgConfig,
-		Password:              flag.GetString(ctx, "password"),
-		SnapshotID:            flag.GetString(ctx, "snapshot-id"),
-		Detach:                flag.GetDetach(ctx),
-		Manager:               flypg.StolonManager,
-		Autostart:             flag.GetBool(ctx, "autostart"),
+	forkFrom := flag.GetString(ctx, "fork-from")
+
+	if forkFrom != "" {
+		// Snapshot ID may not be specified with fork-from
+		if params.SnapshotID != "" {
+			return fmt.Errorf("cannot specify both --fork-from and --snapshot-id")
+		}
+
+		// If initial-cluster-size is not specified, set it to 1
+		if pgConfig.InitialClusterSize == 0 {
+			pgConfig.InitialClusterSize = 1
+		}
+
+		// Initial cluster size may not be greater than 1 with fork-from
+		if pgConfig.InitialClusterSize > 1 {
+			fmt.Fprintf(io.Out, colorize.Yellow("Warning: --initial-cluster-size is ignored when specifying --fork-from\n"))
+			pgConfig.InitialClusterSize = 1
+		}
+
+		// Check to see whether the fork-from value includes a volume ID
+		forkSlice := strings.Split(forkFrom, ":")
+		if len(forkSlice) > 2 {
+			return fmt.Errorf("invalid --fork-from format. See `fly pg create --help` for more information")
+		}
+
+		// Resolve specified fork-from app
+		forkApp, err := client.GetAppCompact(ctx, forkSlice[0])
+		if err != nil {
+			return fmt.Errorf("Failed to resolve the specified fork-from app %s: %w", forkSlice[0], err)
+		}
+
+		// Confirm fork-app is a postgres app
+		if !forkApp.IsPostgresApp() {
+			return fmt.Errorf("The fork-from app %q must be a postgres app", forkApp.Name)
+		}
+
+		ctx, err := apps.BuildContext(ctx, forkApp)
+		if err != nil {
+			return err
+		}
+
+		machines, err := mach.ListActive(ctx)
+		if err != nil {
+			return fmt.Errorf("Failed to list machines associated with %s: %w", forkApp.Name, err)
+		}
+
+		// If the fork-from value includes a volume ID, use that. Otherwise, attempt to resolve the
+		// volume ID associated with the fork-from app's primary instance.
+		if len(forkSlice) == 2 {
+			params.ForkFrom = forkSlice[1]
+		} else {
+			volID, err := resolveForkFromVolume(ctx, machines)
+			if err != nil {
+				return err
+			}
+
+			params.ForkFrom = volID
+		}
+
+		// Resolve the volume
+		vol, err := client.GetVolume(ctx, params.ForkFrom)
+		if err != nil {
+			return fmt.Errorf("Failed to resolve the specified fork-from volume %s: %w", params.ForkFrom, err)
+		}
+
+		// Confirm that the volume is associated with the fork-from app
+		if vol.App.Name != forkApp.Name {
+			return fmt.Errorf("The volume %q specified must be associated with the fork-from app %q", vol.ID, forkApp.Name)
+		}
+
+		// If the region isn't specified, set the region of the fork target
+		reg := flag.GetString(ctx, "region")
+		if reg == "" {
+			reg = vol.Region
+			flag.SetString(ctx, "region", vol.Region)
+		}
+
+		// Confirm that the region matches the region of the fork target
+		if reg != "" && reg != vol.Region {
+			return fmt.Errorf("Target region %q must match the region of the fork volume target: %q", reg, vol.Region)
+		}
+
+		// If the volume size isn't specified, set the volume size of the fork target
+		if pgConfig.DiskGb == 0 {
+			pgConfig.DiskGb = vol.SizeGb
+		}
+
+		// Confirm that the volume size is greater than or equal to the fork target
+		if pgConfig.DiskGb < vol.SizeGb {
+			return fmt.Errorf("The target volume size %dGB must be greater than or equal to the volume fork target: %dGB", pgConfig.DiskGb, vol.SizeGb)
+		}
+
+		// Resolve the fork-from app manager
+		params.Manager = resolveForkFromManager(ctx, machines)
+		params.ForkFrom = vol.ID
 	}
 
-	params.Manager = flypg.ReplicationManager
-	if flag.GetBool(ctx, "stolon") {
-		params.Manager = flypg.StolonManager
+	params.PostgresConfiguration = *pgConfig
+
+	var region *api.Region
+	region, err = prompt.Region(ctx, !org.PaidPlan, prompt.RegionParams{
+		Message: "",
+	})
+	if err != nil {
+		return
+	}
+
+	// Set the default manager if not specified or already resolved
+	if params.Manager == "" {
+		params.Manager = flypg.ReplicationManager
+		if flag.GetBool(ctx, "stolon") {
+			params.Manager = flypg.StolonManager
+		}
 	}
 
 	return CreateCluster(ctx, org, region, params)
@@ -151,6 +262,7 @@ func CreateCluster(ctx context.Context, org *api.Organization, region *api.Regio
 		Region:       region.Code,
 		Manager:      params.Manager,
 		Autostart:    params.Autostart,
+		ForkFrom:     params.ForkFrom,
 	}
 
 	customConfig := params.DiskGb != 0 || params.VMSize != "" || params.InitialClusterSize != 0
@@ -189,7 +301,7 @@ func CreateCluster(ctx context.Context, org *api.Organization, region *api.Regio
 
 	if customConfig {
 		// Resolve cluster size
-		if params.InitialClusterSize == 0 {
+		if params.PostgresConfiguration.InitialClusterSize == 0 {
 			clusterSizePrompt := "Initial cluster size"
 			defaultClusterSize := 2
 
@@ -203,7 +315,7 @@ func CreateCluster(ctx context.Context, org *api.Organization, region *api.Regio
 				return err
 			}
 		}
-		input.InitialClusterSize = params.InitialClusterSize
+		input.InitialClusterSize = params.PostgresConfiguration.InitialClusterSize
 
 		// Resolve VM size
 		vmSize, err := resolveVMSize(ctx, params.VMSize)
@@ -281,6 +393,7 @@ type ClusterParams struct {
 	SnapshotID string
 	Detach     bool
 	Manager    string
+	ForkFrom   string
 	Autostart  bool
 }
 
@@ -426,3 +539,46 @@ func MachineVMSizes() []api.VMSize {
 		},
 	}
 }
+
+func resolveForkFromVolume(ctx context.Context, machines []*api.Machine) (string, error) {
+	if len(machines) == 0 {
+		return "", fmt.Errorf("No machines associated with fork-from target. See `fly pg create --help` for more information")
+	}
+
+	primaryRegion := machines[0].Config.Env["PRIMARY_REGION"]
+
+	// Attempt to resolve the volume associated with the primary machine
+	for _, m := range machines {
+		// Exclude machines that are not in the primary region
+		if m.Config.Env["PRIMARY_REGION"] != primaryRegion {
+			continue
+		}
+
+		role := machineRole(m)
+		// Exclude machines that are not the primary (flex) or leader (stolon)
+		if role != "primary" && role != "leader" {
+			continue
+		}
+
+		return m.Config.Mounts[0].Volume, nil
+	}
+
+	return "", fmt.Errorf("Failed to resolve the volume associated with the primary instance. See `fly pg create --help` for more information")
+}
+
+func resolveForkFromManager(ctx context.Context, machines []*api.Machine) string {
+	if flag.GetBool(ctx, "stolon") {
+		return flypg.StolonManager
+	}
+
+	// We can't resolve the manager type, so we'll default to repmgr
+	if len(machines) == 0 {
+		return flypg.ReplicationManager
+	}
+
+	if machines[0].ImageRef.Labels["fly.pg-manager"] == flypg.ReplicationManager {
+		return flypg.ReplicationManager
+	}
+
+	return flypg.StolonManager
+}
